"use strict";

// Only one entry point
var webpack = require('webpack');

var webpackMerge = require('webpack-merge');

var ExtractCSSChunks = require('extract-css-chunks-webpack-plugin');

var sharedConfig = require('./webpack.shared');

var devConfig = require('./webpack.dev');

var productionConfig = require('./webpack.production');

var baseConfig = function baseConfig(env, argv, envWebpack) {
  var isDev = argv.mode === 'development';
  var shared = sharedConfig(env, argv);
  var config = {
    target: 'web',
    module: {
      rules: [{
        test: /\.(css|scss|sass)$/,
        use: [ExtractCSSChunks.loader, 'css-loader', 'sass-loader']
      }]
    },
    plugins: [new ExtractCSSChunks({
      filename: "[name]".concat(isDev ? '' : '.[chunkhash]', ".css"),
      hot: isDev,
      cssModules: false
    }), new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: JSON.stringify(argv.mode || 'development')
      }
    })]
  };
  return webpackMerge.smart(envWebpack, config, shared);
};

module.exports = function webpackConfig(env, argv) {
  var dev = devConfig;
  var config = null;

  if (argv.mode === 'production') {
    var production = productionConfig(env, argv);
    config = baseConfig(env, argv, production);
  } else {
    config = baseConfig(env, argv, dev);
  }

  return config;
};