"use strict";

var express = require('express');

var _require = require('http'),
    Server = _require.Server;

var slash = require('slash');

var path = require('path');

var webpack = require('webpack');

var webpackDevMiddleware = require('webpack-dev-middleware');

var hotMiddleware = require('webpack-hot-middleware');

var chokidar = require('chokidar');

var fs = require('fs');

var webpackConfig = require('../client-webpack/client.webpack');

var jsMatch = require('../../app-dir/utils/jsMatch');

var c = require('../../app-dir/socket-constants');

var DevSocket = require('./DevSocketManager');

var report = require('../report');

var buildchido = require('../routes-generator/build-chunks'); // check if pagesDir exists in src


var pagesDir = path.join(process.cwd(), '/src/pages');
var hasPages = fs.existsSync(pagesDir);

if (!hasPages) {
  report.failure('make sure ./src/pages folder exists');
}

var clientConfig = webpackConfig(null, {
  mode: 'development'
});
var publicPath = clientConfig.output.publicPath;
var outputPath = clientConfig.output.path;
var PORT = process.env.PORT || 3030;
report.info('building router');
var initialPages = [];

try {
  initialPages = buildchido(); // This is synchronous
} catch (e) {
  report.failure('cannot build chido router', new Error(e));
}

report.success('router build!!!');
var app = express();
var httpApp = Server(app);
DevSocket.init(httpApp);

var Start = function Start() {
  console.clear();
  var ws = DevSocket.getSocket();
  var watcher = chokidar.watch(pagesDir);
  watcher.on('add', function (file) {
    file = slash(file);

    if (!initialPages.includes(file) && jsMatch(file)) {
      report.info("".concat(file, " was added"));
      initialPages = buildchido();
      ws.emit(c.RELOAD);
    }
  }).on('unlink', function (file) {
    report.warn("".concat(file, " was removed"));
    initialPages = buildchido();
    ws.emit(c.RELOAD);
  });
  httpApp.listen(PORT, function () {
    return report.success("[chido] app is in localhost:".concat(PORT));
  });
};

var clientCompiler = webpack(clientConfig);
var devMiddleware = webpackDevMiddleware(clientCompiler, {
  publicPath: publicPath,
  logLevel: 'trace',
  stats: 'errors-only'
});
app.use(devMiddleware);
devMiddleware.waitUntilValid(Start);
app.use(hotMiddleware(clientCompiler, {
  path: '/__webpack_hmr',
  heartbeat: 10 * 1000
}));
app.use(publicPath, express.static(outputPath));
var wildCardHtml = path.join(process.cwd(), '/public/index.html');
app.use('/*', function (req, res) {
  return res.sendFile(wildCardHtml);
});